import os
from global_settings import *

try:
    from local_settings import *
except ImportError:
    import warnings
    warnings.warn('Local settings have not been found (src.conf.local_settings)')

# FORCE_SCRIPT_NAME overrides the interpreted 'SCRIPT_NAME' provided by the
# web server. since the URLs below are used for various purposes outside of
# the WSGI application (static and media files), these need to be updated to
# reflect this alteration
if FORCE_SCRIPT_NAME:
    ADMIN_MEDIA_PREFIX = os.path.join(FORCE_SCRIPT_NAME, ADMIN_MEDIA_PREFIX[1:])

    STATIC_URL = os.path.join(FORCE_SCRIPT_NAME, STATIC_URL[1:])
    MEDIA_URL = os.path.join(FORCE_SCRIPT_NAME, MEDIA_URL[1:])

    LOGIN_URL = os.path.join(FORCE_SCRIPT_NAME, LOGIN_URL[1:])
    LOGOUT_URL = os.path.join(FORCE_SCRIPT_NAME, LOGOUT_URL[1:])
    LOGIN_REDIRECT_URL = os.path.join(FORCE_SCRIPT_NAME, LOGIN_REDIRECT_URL[1:])



import os

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(os.path.dirname(__file__), 'tests.db'),
    }
}

INSTALLED_APPS = (
    '{{ project_name }}',
)

TEST_RUNNER = 'tests.runner.ProfilingTestRunner'
TEST_PROFILE = 'unittest.profile'



import pstats
import cProfile
import unittest
from django.test.simple import DjangoTestSuiteRunner


class ProfilingTestRunner(DjangoTestSuiteRunner):
    def run_suite(self, suite, **kwargs):
        stream = open('profiled_tests.txt', 'w')

        runner = unittest.TextTestRunner(verbosity=self.verbosity, failfast=self.failfast).run

        profile = cProfile.Profile()
        profile.runctx('result = run_tests(suite)', {
            'run_tests': runner,
            'suite': suite,
        }, locals())
        profile.create_stats()
        stats = pstats.Stats(profile, stream=stream)

        stats.sort_stats('time')
        stats.print_stats()
        return locals()['result']



import re
from django.conf.urls import url, patterns, include
from django.conf import settings
from django.contrib import admin
from django.views.generic import TemplateView
from django.template import add_to_builtins

add_to_builtins('avocado.templatetags.avocado_tags')

admin.autodiscover()

urlpatterns = patterns('',
    url(r'^$', TemplateView.as_view(template_name='index.html'), name='index'),

    url(r'', include('cilantro.urls')),

    url(r'^api/', include('serrano.urls')),

    # Administrative components
    url(r'^admin/', include(admin.site.urls)),
)

# In production, these two locations must be served up statically
urlpatterns += patterns('django.views.static',
    url(r'^%s(?P<path>.*)$' % re.escape(settings.MEDIA_URL.lstrip('/')), 'serve', {
        'document_root': settings.MEDIA_ROOT
    }),
    url(r'^%s(?P<path>.*)$' % re.escape(settings.STATIC_URL.lstrip('/')), 'serve', {
        'document_root': settings.STATIC_ROOT
    }),
)



from __future__ import print_function
import re
import os
import sys
import stat
import harvest
from fabric.api import prefix
from fabric.operations import local
from fabric.colors import red, green
from fabric.context_managers import hide, lcd
from harvest.decorators import cli

__doc__ = """\
Creates and sets up a new Harvest project.
"""

HARVEST_TEMPLATE_PATH = os.path.join(os.path.abspath(os.path.dirname(harvest.__file__)), 'template')
STARTPROJECT_ARGS = '--template {} -e py,ini,gitignore,in,conf,md,sample ' \
    '-n Makefile'.format(HARVEST_TEMPLATE_PATH)


def valid_name(name):
    if re.match(r'^[a-z_]\w*$', name, re.I) is not None:
        return True
    return False


@cli(description=__doc__)
def parser(options):
    project_name = options.project_name
    create_env = options.create_env
    verbose = options.verbose

    if not valid_name(project_name):
        print(red("Error: The project name '{}' must be a valid Python "
            "identifier.".format(project_name)))
        sys.exit()

    # Ensure the name does not conflict with an existing Python module
    try:
        __import__(project_name)
        print(red("Error: The project name '{}' conflicts with an existing "
            "Python module. Please choose another name.".format(project_name)))
        sys.exit()
    except ImportError:
        pass

    hidden_output = ['running']
    if not verbose:
        hidden_output.append('stdout')

    with hide(*hidden_output):
        # Check for virtualenv
        if create_env:
            env_path = '{}-env'.format(project_name)
            if os.path.exists(env_path):
                print(red("Error: Cannot create environment '{}'. A " \
                    "directory with the same already exists.".format(env_path)))
                sys.exit()
            print(green("Setting up a virtual environment '{}'...".format(env_path)))
            local('virtualenv {}'.format(env_path))
        else:
            env_path = '.'

        with lcd(env_path):
            with prefix('source bin/activate'):
                print(green('Installing Django...'))
                local('pip install "django>=1.4,<1.5"')

                print(green("Creating new Harvest project '{}'...".format(project_name)))
                local('django-admin.py startproject {} {}'.format(STARTPROJECT_ARGS, project_name))

        with lcd(os.path.join(env_path, project_name)):
            # Ensure manage.py is executable..
            mode = stat.S_IMODE(os.stat('bin/manage.py').st_mode)
            executable = stat.S_IXUSR | stat.S_IXGRP | stat.S_IXOTH
            os.chmod('bin/manage.py', mode | executable)
            with prefix('source ../bin/activate'):
                print(green('Downloading and installing dependencies...'))
                local('pip install -r requirements.txt')

                print(green('Collecting static files...'))
                local('make collect')

    print(green('Setting up a SQLite database...'))
    with hide('running'):
        with lcd(os.path.join(env_path, project_name)):
            with prefix('source ../bin/activate'):
                local('./bin/manage.py syncdb --migrate')
    print(green('''
Complete! Copy and paste the following in your shell:

cd {}/{}
source ../bin/activate
./bin/manage.py runserver

Then open up a web browser and go to: http://localhost:8000
'''.format(env_path, project_name)))


parser.add_argument('project_name', help='Name of the Harvest project. This '
    'must be a valid Python identifier.')
parser.add_argument('--no-env', action='store_false', dest='create_env',
    default=True, help='Prevents creating a virtualenv and sets up the ' \
    'project in the current directory.')
parser.add_argument('--verbose', action='store_true',
    help='Print stdout output during installation process.')



import os
from django.conf import settings

def static(request):
    "Shorthand static URLs. In debug mode, the JavaScript is not minified."
    static_url = settings.STATIC_URL
    prefix = 'src' if settings.DEBUG else 'min'
    return {
        'CSS_URL': os.path.join(static_url, 'stylesheets/css'),
        'IMAGES_URL': os.path.join(static_url, 'images'),
        'JAVASCRIPT_URL': os.path.join(static_url, 'scripts/javascript', prefix),
    }



from __future__ import print_function, with_statement
import os
import json
from functools import wraps
from fabric.api import *
from fabric.colors import red, yellow, white
from fabric.contrib.console import confirm
from fabric.contrib.files import exists


HOSTS_MESSAGE = """\
Before using this fabfile, you must create a .fabhosts in your project
directory. It is a JSON file with the following structure:

    {
        "_": {
            "user": "bruth",
            "host_string": "example.com",
            "path": "~/sites/project-env/project",
            "repo_url": "git@github.com/bruth/project.git",
            "nginx_conf_dir": "~/etc/nginx/conf.d",
            "supervisor_conf_dir": "~/etc/supervisor.d"
        },
        "production": {},
        "development": {
            "path": "~/sites/project-dev-env/project"
        },
        "staging": {
            "path": "~/sites/project-stage-env/project"
        }
    }

The "_" entry acts as the default/fallback for the other host
settings, so you only have to define the host-specific settings.
The below settings are required:

* `user` - username to SSH into the host
* `host_string` - hostname or IP address of the host server
* `path` - path to the deployed project *within* it's virtual environment
* `repo_url` - URL to project git repository
* `nginx_conf_dir` - path to host's nginx conf.d directory
* `supervisor_conf_dir` - path to host's supervisor

Note, additional settings can be defined and will be set on the `env`
object, but the above settings are required at a minimum.
"""

# A few setup steps and environment checks
curdir = os.path.dirname(os.path.abspath(__file__))
hosts_file = os.path.join(curdir, '.fabhosts')

# Check for the .fabhosts file
if not os.path.exists(hosts_file):
    abort(white(HOSTS_MESSAGE))

base_settings = {
    'user': '',
    'host_string': '',
    'path': '',
    'repo_url': '',
    'nginx_conf_dir': '',
    'supervisor_conf_dir': '',
}

required_settings = ['user', 'host_string', 'path', 'repo_url',
    'nginx_conf_dir', 'supervisor_conf_dir']


def get_hosts_settings():
    # Load all the host settings
    hosts = json.loads(open(hosts_file).read())

    # Pop the default settings
    default_settings = hosts.pop('_', {})

    # Pre-populated defaults
    for host in hosts:
        base = base_settings.copy()
        base.update(default_settings)
        base.update(hosts[host])
        hosts[host] = base

    if not env.hosts:
        abort(red('Error: At least one host must be specified'))

    # Validate all hosts have an entry in the .hosts file
    for target in env.hosts:
        if target not in hosts:
            abort(red('Error: No settings have been defined for the "{}" host'.format(target)))
        settings = hosts[target]
        for key in required_settings:
            if not settings[key]:
                abort(red('Error: The setting "{}" is not defined for "{}" host'.format(key, target)))
    return hosts


hosts = get_hosts_settings()

def host_context(func):
    "Sets the context of the setting to the current host"
    @wraps(func)
    def decorator(*args, **kwargs):
        with settings(**hosts[env.host]):
            return func(*args, **kwargs)
    return decorator


@host_context
def merge_commit(commit):
    "Fetches the latest code and merges up the specified commit."
    with cd(env.path):
        run('git fetch')
        run('git merge {}'.format(commit))


@host_context
def syncdb_migrate():
    "Syncs and migrates the database using South."
    verun('./bin/manage.py syncdb --migrate')


@host_context
def symlink_nginx():
    "Symlinks the nginx config to the host's nginx conf directory."
    with cd(env.path):
        run('ln -sf $PWD/server/nginx/{host}.conf '
            '{nginx_conf_dir}/{{ project_name }}-{host}.conf'.format(**env))


@host_context
def reload_nginx():
    "Reloads nginx if the config test succeeds."
    symlink_nginx()

    if run('nginx -t').succeeded:
        pid = run('supervisorctl pid nginx')
        run('kill -HUP {}'.format(pid))
    elif not confirm(yellow('nginx config test failed. continue?')):
        abort('nginx config test failed. Aborting')


@host_context
def reload_supervisor():
    "Re-link supervisor config and force an update to supervisor."
    with cd(env.path):
        run('ln -sf $PWD/server/supervisor/{host}.ini '
            '{supervisor_conf_dir}/{{ project_name }}-{host}.ini'.format(**env))

    run('supervisorctl update')
    run('supervisorctl reread')


@host_context
def reload_wsgi():
    "Gets the PID for the wsgi process and sends a HUP signal."
    pid = run('supervisorctl pid {{ project_name }}')
    run('kill -HUP {}'.format(pid))


@host_context
def deploy(commit, force=False):
    setup()
    upload_settings()
    mm_on()
    merge_commit(commit)
    install_deps(force)
    syncdb_migrate()
    make()
    reload_nginx()
    reload_supervisor()
    reload_wsgi()
    mm_off()


@host_context
def make():
    "Rebuilds all static files using the Makefile."
    with prefix('rvm use default'):
        verun('make')


@host_context
def setup():
    "Sets up the initial environment."
    parent, project = os.path.split(env.path)

    if not exists(parent):
        run('virtualenv {}'.format(parent))

    with cd(parent):
        if not exists(project):
            run('git clone {repo_url} {project}'.format(project=project, **env))


@host_context
def upload_settings():
    "Uploads the non-versioned local settings to the server."
    local_path = os.path.join(curdir, 'settings/{}.py'.format(env.host))
    if os.path.exists(local_path):
        remote_path = os.path.join(env.path, '{{ project_name }}/conf/local_settings.py')
        local('scp {local_path} {user}@{host_string}:{remote_path}'\
            .format(local_path=local_path, remote_path=remote_path, **env))
    elif not confirm(yellow('No local settings found for host "{}". Continue anyway?'.format(env.host))):
        abort('No local settings found for host "{}". Aborting.')


@host_context
def install_deps(force=False):
    "Install dependencies via pip."
    if force:
        verun('pip install -U -r requirements.txt')
    else:
        verun('pip install -r requirements.txt')


@host_context
def verun(cmd):
    "Runs a command after the virtualenv is activated."
    with cd(env.path):
        with prefix('source ../bin/activate'):
            run(cmd)


@host_context
def mm_on():
    "Turns on maintenance mode."
    with cd(env.path):
        run('touch MAINTENANCE_MODE')


@host_context
def mm_off():
    "Turns off maintenance mode."
    with cd(env.path):
        run('rm -f MAINTENANCE_MODE')



from argparse import ArgumentParser


def cached_property(func):
    cach_attr = '_{}'.format(func.__name__)

    @property
    def wrap(self):
        if not hasattr(self, cach_attr):
            value = func(self)
            if value is not None:
                setattr(self, cach_attr, value)
        return getattr(self, cach_attr, None)
    return wrap


def cli(*args, **kwargs):
    def decorator(func):
        class Parser(ArgumentParser):
            def handle(self, *args, **kwargs):
                try:
                    func(*args, **kwargs)
                except Exception, e:
                    self.error(e.message)

            # No catching of exceptions
            def handle_raw(self, *args, **kwargs):
                func(*args, **kwargs)

        return Parser(*args, **kwargs)
    return decorator



import os
from global_settings import PROJECT_PATH

# Uncomment to put the application in non-debug mode. This is useful
# for testing error handling and messages.
# DEBUG = False
# TEMPLATE_DEBUG = DEBUG

# Override this to match the application endpoint
# FORCE_SCRIPT_NAME = ''

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(PROJECT_PATH, '{{ project_name }}.db')
    }
}

# Non-restricted email port for development, run in a terminal:
# python -m smtpd -n -c DebuggingServer localhost:1025
EMAIL_PORT = 1025
EMAIL_SUBJECT_PREFIX = '[{{ project_name }} Local] '

# This is used as a "seed" for various hashing algorithms. This must be set to
# a very long random string (40+ characters)
SECRET_KEY = '{{ secret_key }}'



import os
import sys

sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))

os.environ.setdefault('DJANGO_SETTINGS_MODULE', '{{ project_name }}.conf.settings')
os.environ.setdefault('PYTHON_EGG_CACHE', '/tmp')

# This application object is used by any WSGI server configured to use this
# file. This includes Django's development server, if the WSGI_APPLICATION
# setting points here.
from django.core.wsgi import get_wsgi_application
application = get_wsgi_application()



from setuptools import setup, find_packages

PACKAGE = '{{ project_name }}'
VERSION = __import__(PACKAGE).get_version()

kwargs = {
    'name': PACKAGE,
    'version': VERSION,
    'packages': find_packages(),
    'test_suite': 'test_suite',
    'author': '',
    'author_email': '',
    'description': '',
    'license': '',
    'keywords': '',
    'url': '',
    'classifiers': [],
}

setup(**kwargs)



#!/usr/bin/env python
import os
import sys

# Add the project to the path
sys.path.insert(0, os.path.dirname(os.path.dirname(__file__)))

# setup the environment
os.environ.setdefault('DJANGO_SETTINGS_MODULE', '{{ project_name }}.conf.settings')
os.environ.setdefault('PYTHON_EGG_CACHE', '/tmp')

from django.core.management import execute_from_command_line
execute_from_command_line()



import os

# Import global settings to make it easier to extend settings.
from django.conf.global_settings import *

# Import the project module to calculate directories relative to the module
# location.
PROJECT_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), '../..')

# List all Django apps here. Note that standard Python libraries should not
# be added to this list since Django will not recognize them as apps anyway.
# An app is really only an "app" if a `models` module or package is defined.
# Read more about projects vs. apps here:
# https://docs.djangoproject.com/en/1.3/intro/tutorial01/#creating-models
INSTALLED_APPS = (
    '{{ project_name }}',

    'south',
    'cilantro',
    'serrano',
    'avocado',

    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.humanize',
    'django.contrib.markup',
    'django.contrib.messages',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.staticfiles',
)


#
# ADMINISTRATIVE
#

# Admins receive any error messages by email if DEBUG is False
ADMINS = ()

# Managers receive broken link emails if SEND_BROKEN_LINK_EMAILS is True
MANAGERS = ADMINS

# List of IP addresses which will show debug comments
INTERNAL_IPS = ('127.0.0.1', '::1')

DEBUG = True
TEMPLATE_DEBUG = DEBUG


#
# DATABASES
# Each database can be specified here, but passwords should be in a separate
# file that is not versioned. Use ``local_settings.py``.
#

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(PROJECT_PATH, '{{ project_name }}.db')
    }
}


#
# LOCALITY
#

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = None

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'en-us'

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = False

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale
USE_L10N = False


#
# STATIC AND MEDIA
# The application's static files should be placed in the STATIC_ROOT in
# addition to other static files found in third-party apps. The MEDIA_ROOT
# is intended for user uploaded files.
#

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = os.path.join(PROJECT_PATH, '_site/media')

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = '/media/'

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = os.path.join(PROJECT_PATH, '_site/static')

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# URL prefix for admin static files -- CSS, JavaScript and images.
# Make sure to use a trailing slash.
# Examples: "http://foo.com/static/admin/", "/static/admin/".
ADMIN_MEDIA_PREFIX = '/static/admin/'

# Additional locations of static files
# Put strings here, like "/home/html/static" or "C:/www/django/static".
# Always use forward slashes, even on Windows.
# Don't forget to use absolute paths, not relative paths.
STATICFILES_DIRS = ()

#
# TEMPLATES
#

# Project level templates and template directories that override
# third-party app templates.
TEMPLATE_DIRS = ()

# Context processors are simply functions that return a dict which augments the
# template context.
TEMPLATE_CONTEXT_PROCESSORS += (
    'django.core.context_processors.request',
    '{{ project_name }}.context_processors.static',
    'cilantro.context_processors.cilantro',
)


#
# URLS
#

# FORCE_SCRIPT_NAME overrides the interpreted 'SCRIPT_NAME' provided by the
# web server. since the URLs below are used for various purposes outside of
# the WSGI application (static and media files), these need to be updated to
# reflect this discrepancy.
FORCE_SCRIPT_NAME = ''

ROOT_URLCONF = '{{ project_name }}.conf.urls'

# LOGIN_URL = '/login/'
# LOGOUT_URL = '/logout/'

# For non-publicly accessible applications, the siteauth app can be used to
# restrict access site-wide.
# SITEAUTH_ACCESS_ORDER = 'allow/deny'
#
# SITEAUTH_ALLOW_URLS = (
#     r'^$',
#     r'^log(in|out)/',
#     r'^password/reset/',
#     r'^(register|verify)/',
# )

#
# MIDDLEWARE
#

MIDDLEWARE_CLASSES = (
    'django.middleware.gzip.GZipMiddleware',
    # 'django.middleware.cache.UpdateCacheMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'serrano.middleware.SessionMiddleware',
    # 'django.middleware.cache.FetchFromCacheMiddleware',
)


#
# EMAIL
#

SUPPORT_EMAIL = 'support@example.com'
DEFAULT_FROM_EMAIL = 'support@example.com'
EMAIL_SUBJECT_PREFIX = '[{{ project_name }}] '
SEND_BROKEN_LINK_EMAILS = False


#
# LOGGING
#

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}


#
# CACHE
#

# For production environments, the memcached backend is highly recommended
CACHES = {
    'default': {
        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
        'LOCATION': 'unique',
        'KEY_PREFIX': '{{ project_name}}',
        'VERSION': 1,
    }
}

CACHE_MIDDLEWARE_SECONDS = 0

# This is not necessary to set if the above `KEY_PREFIX` value is set since
# the `KEY_PREFIX` namespaces all cache set by this application
CACHE_MIDDLEWARE_KEY_PREFIX = '{{ project_name }}'


#
# SESSIONS AND COOKIES
#

CSRF_COOKIE_NAME = '{{ project_name }}_csrftoken'

# SESSION_COOKIE_AGE = 60 * 20
SESSION_ENGINE = 'django.contrib.sessions.backends.cache'
SESSION_COOKIE_NAME = '{{ project_name }}_sessionid'
SESSION_EXPIRE_AT_BROWSER_CLOSE = False
SESSION_SAVE_EVERY_REQUEST = False


#
# OTHER PROJECT SETTINGS
#

# USE_ETAGS = True
IGNORABLE_404_PATHS = (
    r'robots.txt$',
    r'favicon.ico$',
)

#
# VARIOUS APP SETTINGS
#

# The primary key of the ``Site`` object for the Sites Framework
SITE_ID = 1



from __future__ import print_function
import os
from fabric.operations import local
from fabric.context_managers import hide
from harvest.decorators import cli

__doc__ = """\
Updates this Harvest package.
"""


@cli(description=__doc__)
def parser(options):
    with hide('running'):
        bindir = os.path.dirname(local('which harvest', capture=True))
        pip = os.path.join(bindir, 'pip')
        local('{} install -U harvest'.format(pip))



from setuptools import setup, find_packages


kwargs = {
    # Packages
    'packages': find_packages(exclude=['tests', '*.tests', '*.tests.*', 'tests.*']),
    'include_package_data': True,

    # Dependencies
    'install_requires': [
        'fabric>=1.4.3',
        'virtualenv>=1.8.2',
    ],

    'test_suite': 'tests',

    'scripts': ['bin/harvest'],

    # Metadata
    'name': 'harvest',
    'version': __import__('harvest').get_version(),
    'author': 'The Children\'s Hospital of Philadelphia',
    'author_email': 'cbmisupport@email.chop.edu',
    'description': 'Harvest project template',
    'license': 'BSD',
    'keywords': 'harvest metadata avocado serrano cilantro django',
    'url': 'http://cbmi.github.com/harvest/',
    'classifiers': [
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python :: 2.7',
        'Framework :: Django',
        'Topic :: Internet :: WWW/HTTP',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Information Technology',
    ],
}

setup(**kwargs)
